@@ -4,13 +4,33 @@ from typing import List, Optional
 # SUPER-CLASS
 class RiotApiResponse:
     def __init__(self, succeed: bool = True):
-        self.succeed = succeed
+        self.success = succeed
         self.error = not succeed
     
     def __str__(self):
-        return '{}({})'.format(
+        return self.__str()
+    
+    def __str(self, level: int = 0, sep = '    '):
+        def recursion(obj, level: int = level, sep = sep):
+            if isinstance(obj, RiotApiResponse):
+                return obj.__str(level + 1, sep)
+            if isinstance(obj, list):
+                return f'[\n{sep * (level + 2)}' + (
+                    f',\n{sep * (level + 2)}'.join(
+                        map(lambda x: recursion(x, level + 1, sep), obj)
+                    )) + f'\n{sep * (level + 1)}]'
+            return obj
+        
+        return '{}(\n{}{}\n{})'.format(
             type(self).__name__,
-            ', '.join('{} = {}'.format(*item) for item in vars(self).items())
+            sep * (level + 1),
+            f',\n{sep * (level + 1)}'.join(
+                '{} = {}'.format(*item) for item in map(
+                    lambda x: (x[0], recursion(x[1])),
+                    filter(lambda x: x[0] not in ['success', 'error'], vars(self).items())
+                )
+            ),
+            sep * level,
         )
     
     def __repr__(self):
